@@ -55,10 +55,10 @@ var searchData=
   ['enable_3c_20t_2c_20true_20_3e_52',['Enable&lt; T, true &gt;',['../a00730.html',1,'rtl::libreoffice_internal']]],
   ['enablechangelistenernotification_53',['enableChangeListenerNotification',['../a01926.html#a01ee4368d1b29b8610baad98a3097cec',1,'cppu::OPropertySetHelper2']]],
   ['enablenonblockingmode_54',['enableNonBlockingMode',['../a00858.html#ada1ee513556e62e7058c522992ffcf13',1,'osl::Socket']]],
-  ['encode_55',['encode',['../a00746.html#a448fa7e0d5403c180c1f59cae1867e77',1,'rtl::Uri::encode(rtl::OUString const &amp;rText, rtl_UriCharClass eCharClass, rtl_UriEncodeMechanism eMechanism, rtl_TextEncoding eCharset)'],['../a00746.html#acb69b2efad453d22779fe5ffa6d8f2a6',1,'rtl::Uri::encode(rtl::OUString const &amp;rText, sal_Bool const *pCharClass, rtl_UriEncodeMechanism eMechanism, rtl_TextEncoding eCharset)'],['../a00610.html#a1e84db69fd5b4b86a6a92b1eb547adb6',1,'rtl::Bootstrap::encode()']]],
-  ['end_56',['end',['../a01010.html#aa6765e6c72caadf94d802a3f6280f770',1,'com::sun::star::uno::Sequence::end() const'],['../a01010.html#a6aa569da57fb65c4b001fec1e80fe902',1,'com::sun::star::uno::Sequence::end()']]],
+  ['encode_55',['encode',['../a00610.html#a1e84db69fd5b4b86a6a92b1eb547adb6',1,'rtl::Bootstrap::encode()'],['../a00746.html#acb69b2efad453d22779fe5ffa6d8f2a6',1,'rtl::Uri::encode(rtl::OUString const &amp;rText, sal_Bool const *pCharClass, rtl_UriEncodeMechanism eMechanism, rtl_TextEncoding eCharset)'],['../a00746.html#a448fa7e0d5403c180c1f59cae1867e77',1,'rtl::Uri::encode(rtl::OUString const &amp;rText, rtl_UriCharClass eCharClass, rtl_UriEncodeMechanism eMechanism, rtl_TextEncoding eCharset)']]],
+  ['end_56',['end',['../a01010.html#a6aa569da57fb65c4b001fec1e80fe902',1,'com::sun::star::uno::Sequence::end()'],['../a01010.html#aa6765e6c72caadf94d802a3f6280f770',1,'com::sun::star::uno::Sequence::end() const']]],
   ['endian_2eh_57',['endian.h',['../a00233.html',1,'']]],
-  ['endswith_58',['endsWith',['../a00666.html#ae74d8d826f8bb6590454135348454f85',1,'rtl::OString::endsWith()'],['../a00754.html#abd00c579b6f686891f4aa7d73f38c873',1,'rtl::OUString::endsWith(T &amp;literal, OUString *rest=NULL) const'],['../a00754.html#a0a9dd4283c1651c8e0261077273d48dc',1,'rtl::OUString::endsWith(OUString const &amp;str, OUString *rest=NULL) const'],['../a00666.html#a124086ebe8d9159db2c703b030961ee6',1,'rtl::OString::endsWith()']]],
+  ['endswith_58',['endsWith',['../a00666.html#ae74d8d826f8bb6590454135348454f85',1,'rtl::OString::endsWith(OString const &amp;str, OString *rest=NULL) const'],['../a00666.html#a124086ebe8d9159db2c703b030961ee6',1,'rtl::OString::endsWith(T &amp;literal, OString *rest=NULL) const'],['../a00754.html#a0a9dd4283c1651c8e0261077273d48dc',1,'rtl::OUString::endsWith(OUString const &amp;str, OUString *rest=NULL) const'],['../a00754.html#abd00c579b6f686891f4aa7d73f38c873',1,'rtl::OUString::endsWith(T &amp;literal, OUString *rest=NULL) const']]],
   ['endswithasciil_59',['endsWithAsciiL',['../a00754.html#a1dce9523dbc575f14cd2212cef2ddcdc',1,'rtl::OUString']]],
   ['endswithignoreasciicase_60',['endsWithIgnoreAsciiCase',['../a00754.html#a6a6bff8a9b0f6f4d5fc521ef9c459024',1,'rtl::OUString::endsWithIgnoreAsciiCase(OUString const &amp;str, OUString *rest=NULL) const'],['../a00754.html#ad6166e0daedd9662e4151e9f154138dd',1,'rtl::OUString::endsWithIgnoreAsciiCase(T &amp;literal, OUString *rest=NULL) const']]],
   ['endswithignoreasciicaseasciil_61',['endsWithIgnoreAsciiCaseAsciiL',['../a00754.html#a0ccd5e8634080334c40d7dccbde3c878',1,'rtl::OUString']]],
@@ -66,28 +66,28 @@ var searchData=
   ['ensurecapacity_63',['ensureCapacity',['../a00662.html#a926ea93d243f4fcab5c01c3a6672ebb4',1,'rtl::OStringBuffer::ensureCapacity()'],['../a00750.html#ac0749937b466886d614acc4e144a2cfc',1,'rtl::OUStringBuffer::ensureCapacity()']]],
   ['enter_64',['enter',['../a00982.html#afefdf7e25ee12121ee133161a6d0cf7a',1,'com::sun::star::uno::Environment::enter()'],['../a00994.html#a21a802ef1b6d3b4b52a370deed148731',1,'cppu::Enterable::enter()']]],
   ['enterable_65',['Enterable',['../a00994.html',1,'cppu::Enterable'],['../a00994.html#ac0de3fa18a9bc16ae90ede2a2ee046f2',1,'cppu::Enterable::Enterable()']]],
-  ['enterable_2eh_66',['Enterable.h',['../a00272.html',1,'']]],
-  ['enterable_2ehxx_67',['Enterable.hxx',['../a00305.html',1,'']]],
+  ['enterable_2eh_66',['Enterable.h',['../a00278.html',1,'']]],
+  ['enterable_2ehxx_67',['Enterable.hxx',['../a00308.html',1,'']]],
   ['enterable_5fcall_5fcallinto_5fv_68',['Enterable_call_callInto_v',['../a00537.html#aaf16fcbae344040f79a7bfb7b58db472',1,'cppu']]],
   ['enterable_5fcall_5fcallout_5fv_69',['Enterable_call_callOut_v',['../a00537.html#af3d1078ecf59fc64e6ef2e365fef342e',1,'cppu']]],
   ['enterable_5fcall_5fenter_70',['Enterable_call_enter',['../a00537.html#a29d40bff6c05fb084d4fa3f39d6af066',1,'cppu']]],
   ['enterable_5fcall_5fisvalid_71',['Enterable_call_isValid',['../a00537.html#a6af9bf435c6a006cfe84fd87b3ba0f4d',1,'cppu']]],
   ['enterable_5fcall_5fleave_72',['Enterable_call_leave',['../a00537.html#ae497668d91aa3754adb4189fefc5d2e8',1,'cppu']]],
   ['envdcp_2eh_73',['EnvDcp.h',['../a00284.html',1,'']]],
-  ['envdcp_2ehxx_74',['EnvDcp.hxx',['../a00329.html',1,'']]],
+  ['envdcp_2ehxx_74',['EnvDcp.hxx',['../a00317.html',1,'']]],
   ['envguard_75',['EnvGuard',['../a00998.html',1,'cppu::EnvGuard'],['../a00998.html#adabaaf6b5a8445668f0725cfe86fa02a',1,'cppu::EnvGuard::EnvGuard()']]],
-  ['envguards_2ehxx_76',['EnvGuards.hxx',['../a00317.html',1,'']]],
+  ['envguards_2ehxx_76',['EnvGuards.hxx',['../a00320.html',1,'']]],
   ['environment_77',['Environment',['../a00982.html',1,'com::sun::star::uno::Environment'],['../a00982.html#a52c8a36837ad58e98784f549cd95b3ed',1,'com::sun::star::uno::Environment::Environment(uno_Environment *pEnv=NULL)'],['../a00982.html#a1224d0b31212c4465973b6652dd4c504',1,'com::sun::star::uno::Environment::Environment(rtl::OUString const &amp;envDcp, void *pContext=NULL)'],['../a00982.html#a76d19e18ab8d0d898fb552cba029e0d9',1,'com::sun::star::uno::Environment::Environment(const Environment &amp;rEnv)']]],
-  ['environment_2eh_78',['environment.h',['../a00302.html',1,'']]],
+  ['environment_2eh_78',['environment.h',['../a00281.html',1,'']]],
   ['environment_2ehxx_79',['Environment.hxx',['../a02516.html',1,'']]],
   ['environment_2ehxx_80',['environment.hxx',['../a02519.html',1,'']]],
   ['environment_5finitwithenterable_81',['Environment_initWithEnterable',['../a00540.html#a6acec576bc79a431fd632b7a73a65f3e',1,'cppu::helper::purpenv']]],
   ['environmentdisposing_82',['environmentDisposing',['../a00974.html#a769c1f529abc0ec4435717d8d31c0dff',1,'_uno_Environment']]],
   ['equalint32_5fimpl_83',['equalInt32_Impl',['../a01906.html',1,'cppu']]],
-  ['equals_84',['equals',['../a00950.html#a9234418ef5a517af5c6e6f0b1d55f35a',1,'com::sun::star::uno::TypeDescription::equals()'],['../a00666.html#ae8c738b6b1acf0209996a759000f4529',1,'rtl::OString::equals()'],['../a00754.html#af8906c3531fdab1b1ea30ffec22bbc15',1,'rtl::OUString::equals()'],['../a00950.html#ac9a86d17cc6ae80b74f0c2a104f3e9ca',1,'com::sun::star::uno::TypeDescription::equals()'],['../a01974.html#a551931cdcaa98bceedd76d8206d80521',1,'com::sun::star::uno::Type::equals()']]],
+  ['equals_84',['equals',['../a00666.html#ae8c738b6b1acf0209996a759000f4529',1,'rtl::OString::equals()'],['../a00754.html#af8906c3531fdab1b1ea30ffec22bbc15',1,'rtl::OUString::equals()'],['../a00950.html#a9234418ef5a517af5c6e6f0b1d55f35a',1,'com::sun::star::uno::TypeDescription::equals(const typelib_TypeDescription *pTypeDescr) const'],['../a00950.html#ac9a86d17cc6ae80b74f0c2a104f3e9ca',1,'com::sun::star::uno::TypeDescription::equals(const TypeDescription &amp;rTypeDescr) const'],['../a01974.html#a551931cdcaa98bceedd76d8206d80521',1,'com::sun::star::uno::Type::equals()']]],
   ['equalsascii_85',['equalsAscii',['../a00754.html#a975abdfbab9e0c78c10307df1a5ebaa7',1,'rtl::OUString']]],
   ['equalsasciil_86',['equalsAsciiL',['../a00754.html#a5e2609800c4992774b08c8a7d2c07436',1,'rtl::OUString']]],
-  ['equalsignoreasciicase_87',['equalsIgnoreAsciiCase',['../a00666.html#ad757daff373e4845cd7930a8af3eef98',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;asciiStr) const'],['../a00666.html#ace69f01af1e5bbd09d6fde970254f4b9',1,'rtl::OString::equalsIgnoreAsciiCase(const OString &amp;str) const'],['../a00666.html#adbbf466e411d68099894f0511fa49ca1',1,'rtl::OString::equalsIgnoreAsciiCase(const T &amp;asciiStr) const'],['../a00754.html#a51cd29980d7962cc7c5fce9781ea27b3',1,'rtl::OUString::equalsIgnoreAsciiCase(T &amp;literal) const'],['../a00754.html#a19c4188312d907a6267d9ca435ff0e84',1,'rtl::OUString::equalsIgnoreAsciiCase(const OUString &amp;str) const'],['../a00666.html#a41b89297b85dc79db79bd2d91172975b',1,'rtl::OString::equalsIgnoreAsciiCase()']]],
+  ['equalsignoreasciicase_87',['equalsIgnoreAsciiCase',['../a00666.html#ace69f01af1e5bbd09d6fde970254f4b9',1,'rtl::OString::equalsIgnoreAsciiCase(const OString &amp;str) const'],['../a00666.html#adbbf466e411d68099894f0511fa49ca1',1,'rtl::OString::equalsIgnoreAsciiCase(const T &amp;asciiStr) const'],['../a00666.html#ad757daff373e4845cd7930a8af3eef98',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;asciiStr) const'],['../a00666.html#a41b89297b85dc79db79bd2d91172975b',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;literal) const'],['../a00754.html#a19c4188312d907a6267d9ca435ff0e84',1,'rtl::OUString::equalsIgnoreAsciiCase(const OUString &amp;str) const'],['../a00754.html#a51cd29980d7962cc7c5fce9781ea27b3',1,'rtl::OUString::equalsIgnoreAsciiCase(T &amp;literal) const']]],
   ['equalsignoreasciicaseascii_88',['equalsIgnoreAsciiCaseAscii',['../a00754.html#aad245e6979066dc481bd116d413e7cf8',1,'rtl::OUString']]],
   ['equalsignoreasciicaseasciil_89',['equalsIgnoreAsciiCaseAsciiL',['../a00754.html#a2245d3d40c15586202e3f953c1a7cfbc',1,'rtl::OUString']]],
   ['equalsignoreasciicasel_90',['equalsIgnoreAsciiCaseL',['../a00666.html#afa008446aca7017ee3bfa130eeba6be1',1,'rtl::OString']]],
@@ -95,8 +95,8 @@ var searchData=
   ['erf_92',['erf',['../a00534.html#a10d1970a09b2058e6c67aaf3d996bc81',1,'rtl::math']]],
   ['erfc_93',['erfc',['../a00534.html#a925bcacd0739af847e6ea7313f55ff13',1,'rtl::math']]],
   ['etype_94',['eType',['../a00766.html#a53100ddce23ca881ef927cc7a7e4082c',1,'_oslFileStatus']]],
-  ['etypeclass_95',['eTypeClass',['../a00894.html#ab0d5de22f9bea87a040aea35edb65455',1,'_typelib_TypeDescriptionReference::eTypeClass'],['../a00946.html#a5bf8cfd96c617fe998cd7b4b9f2a6f6d',1,'_typelib_Parameter_Init::eTypeClass'],['../a00938.html#a92b247165b3b569fe2b20d2ac9b15399',1,'_typelib_CompoundMember_Init::eTypeClass'],['../a00898.html#a8dcfc477b933d5c19661adab1e5c0aaf',1,'_typelib_TypeDescription::eTypeClass']]],
-  ['exc_5fhlp_2ehxx_96',['exc_hlp.hxx',['../a00389.html',1,'']]],
+  ['etypeclass_95',['eTypeClass',['../a00894.html#ab0d5de22f9bea87a040aea35edb65455',1,'_typelib_TypeDescriptionReference::eTypeClass'],['../a00898.html#a8dcfc477b933d5c19661adab1e5c0aaf',1,'_typelib_TypeDescription::eTypeClass'],['../a00938.html#a92b247165b3b569fe2b20d2ac9b15399',1,'_typelib_CompoundMember_Init::eTypeClass'],['../a00946.html#a5bf8cfd96c617fe998cd7b4b9f2a6f6d',1,'_typelib_Parameter_Init::eTypeClass']]],
+  ['exc_5fhlp_2ehxx_96',['exc_hlp.hxx',['../a00401.html',1,'']]],
   ['execute_97',['execute',['../a00598.html#ae36a1d715a7d32e7ba9faf54cadd6e39',1,'salhelper::Thread']]],
   ['expandmacros_98',['expandMacros',['../a00610.html#af7d23f65eb618ed9b7c55067e82a842b',1,'rtl::Bootstrap']]],
   ['expandmacrosfrom_99',['expandMacrosFrom',['../a00610.html#a1e68296a30cfebe0ec395176e7e933c3',1,'rtl::Bootstrap']]],
